<?php

namespace Drupal\prelinker\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Prelinker settings
 */
class PrelinkerSettings extends ConfigFormBase
{
    /**
     * {@inheritdoc}
     */
    public function getFormId()
    {
        return 'prelinker_config_form';
    }

    /**
     * {@inheritdoc}
     */
    protected function getEditableConfigNames()
    {
        return ['prelinker.settings'];
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state)
    {
        $config = $this->config('prelinker.settings');

        $form['preconnect'] = [
            '#type' => 'fieldset',
            '#title' => $this->t('Preconnect settings'),
            'preconnect_head' => [
                '#type' => 'checkbox',
                '#required' => false,
                '#title' => $this->t('Include in the &lt;head&gt; section as &lt;link&gt; elements'),
                '#description' => $this->t('When enabled, each preconnect domain will be added as a &lt;link&gt; element to the &lt;head&gt; section of page.'),
                '#default_value' => !empty($config->get('preconnect_head'))
            ],
            'preconnect_push' => [
                '#type' => 'checkbox',
                '#required' => false,
                '#title' => $this->t('Include in the response headers for HTTP/2 push'),
                '#description' => $this->t('When enabled, each preconnect domain will be added to the response headers'),
                '#default_value' => !empty($config->get('preconnect_push'))
            ],
        ];

        $form['preload'] = [
            '#type' => 'fieldset',
            '#title' => $this->t('Preload settings'),
            'preload_head' => [
                '#type' => 'checkbox',
                '#required' => false,
                '#title' => $this->t('Include in the &lt;head&gt; section as &lt;link&gt; elements'),
                '#description' => $this->t('When enabled, each preload file will be added as a &lt;link&gt; element to the &lt;head&gt; section of page.'),
                '#default_value' => !empty($config->get('preload_head'))
            ],
            'preload_push' => [
                '#type' => 'checkbox',
                '#required' => false,
                '#title' => $this->t('Include in the response headers for HTTP/2 push'),
                '#description' => $this->t('When enabled, each preload file will be added to the response headers'),
                '#default_value' => !empty($config->get('preload_push'))
            ],
        ];

        $form['http2'] = [
            '#type' => 'fieldset',
            '#title' => $this->t('HTTP/2 push settings'),
            'preload_push_image' => [
                '#type' => 'checkbox',
                '#required' => false,
                '#title' => $this->t('Scan the document for data-preload-image="" and add to the response headers'),
                '#default_value' => !empty($config->get('preload_push_image'))
            ],
            'preload_push_css' => [
                '#type' => 'checkbox',
                '#required' => false,
                '#title' => $this->t('Scan the document for included CSS files and add to the response headers'),
                '#default_value' => !empty($config->get('preload_push_css'))
            ],
            'preload_push_preload' => [
                '#type' => 'checkbox',
                '#required' => false,
                '#title' => $this->t('Scan the document for existing preload links and add to the response headers'),
                '#default_value' => !empty($config->get('preload_push_preload'))
            ],
            'preload_push_preconnect' => [
                '#type' => 'checkbox',
                '#required' => false,
                '#title' => $this->t('Scan the document for existing preconnect links and add to the response headers'),
                '#default_value' => !empty($config->get('preload_push_preconnect'))
            ],
        ];

        return parent::buildForm($form, $form_state);
    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state)
    {
        parent::submitForm($form, $form_state);

        $this->config('prelinker.settings')->set(
            'preconnect_head',
            $form_state->getValue('preconnect_head')
        )->set(
            'preconnect_push',
            $form_state->getValue('preconnect_push')
        )->set(
            'preload_head',
            $form_state->getValue('preload_head')
        )->set(
            'preload_push',
            $form_state->getValue('preload_push')
        )->set(
            'preload_push_image',
            $form_state->getValue('preload_push_image')
        )->set(
            'preload_push_css',
            $form_state->getValue('preload_push_css')
        )->set(
            'preload_push_preload',
            $form_state->getValue('preload_push_preload')
        )->set(
            'preload_push_preconnect',
            $form_state->getValue('preload_push_preconnect')
        )->save();
    }
}
